#
# spec file for package libdnf
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2019 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%if (0%{?sle_version} && 0%{?sle_version} < 150200)
    %global libsolv_version 0.7.3
%else
    %global libsolv_version 0.7.4
%endif

%global libmodulemd_version 1.6.1
%global librepo_version 1.9.6
%global swig_version 3.0.12

# Keep tests switched off for now, it bombs out on SUSE
%bcond_with check

# Keep valgrind tests switched off for now
%bcond_with valgrind

%define somajor 2
%define libname %{name}%{somajor}
%define devname %{name}-devel

Name:           libdnf
Version:        0.31.0
Release:        lp151.1.1
Summary:        Library providing C and Python APIs atop libsolv
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Url:            https://github.com/rpm-software-management/%{name}
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz

# PATCH-FIX-OPENSUSE: Fix libdnf build with static libsolvext
Patch1000:      libdnf-0.28.1-with-static-libsolvext.patch
# PATCH-FIX-OPENSUSE: Switch default reposdir to /etc/dnf/repos.d
Patch1001:      libdnf-0.28.1-Switch-default-reposdir-to-etc-dnf-repos.d.patch

# PATCH-FIX-SLE: Revert support for module advisories, since that requires libsolv 0.7.4
## Drop when bsc#1133527 is fixed
Patch2001:      libdnf-0.31.0-Revert-support-for-Module-advisories.patch

BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gpgme-devel
BuildRequires:  libsolv-devel >= %{libsolv_version}
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(librepo) >= %{librepo_version}
%if %{with valgrind}
BuildRequires:  valgrind
%endif
BuildRequires:  rpm-devel >= 4.11.0
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.46.0
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(modulemd) >= %{libmodulemd_version}
BuildRequires:  pkgconfig(smartcols)
BuildRequires:  pkgconfig(sqlite3)

# libsolv specific BRs
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(zlib)

%description
This library provides a high level RPM package manager that can be integrated
into applications to manage software. It is currently used by DNF, RPM-OSTree,
and PackageKit.

%package -n %{libname}
Summary:        Library providing an interface atop libsolv
Group:          System/Libraries
Recommends:     %{name}-lang = %{version}-%{release}
# gobject-introspection is no longer used
Obsoletes:      typelib-1_0-Dnf-1_0 < 0.24.1
# To avoid API issues with librepo and incomprehensible crashes
Requires:       librepo0%{?_isa} >= %{librepo_version}

%description -n %{libname}
This library provides an interface atop libsolv, and a high-level
RPM package manager library interface.

%package -n python3-%{name}
Summary:        Python 3 bindings for the libdnf library
Group:          Development/Libraries/Python
Requires:       %{libname}%{?_isa} = %{version}-%{release}
BuildRequires:  python3-Sphinx
BuildRequires:  python3-devel
BuildRequires:  swig >= %{swig_version}

%description -n python3-%{name}
This package provides the Python 3 bindings for the libdnf library.

%package -n %{devname}
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n %{devname}
This package provides the headers and libraries for developing applications
that use %{name}.

%package -n hawkey-man
Summary:        Documentation for the hawkey Python bindings
Group:          Documentation/Man
BuildRequires:  python3-Sphinx
BuildRequires:  python3-nose
BuildArch:      noarch

%description -n hawkey-man
This package provides the man pages for the hawkey Python bindings.

%package -n python3-hawkey
Summary:        Python 3 bindings for the hawkey interface
Group:          Development/Libraries/Python
BuildRequires:  python3-devel
BuildRequires:  python3-nose
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       python3-%{name}%{?_isa} = %{version}-%{release}
Recommends:     hawkey-man = %{version}-%{release}
# DNF older than 4.0.0 isn't compatible with this
Conflicts:      python3-dnf < 4.0.0
# Python 2 subpackage has been dropped
Obsoletes:      python2-hawkey < 0.24.1

%description -n python3-hawkey
This package provides the Python 3 bindings for %{name} through
the hawkey interface.

%lang_package


%prep
%autosetup -p1

%if (0%{?sle_version} && 0%{?sle_version} > 150100) || 0%{?suse_version} > 1500
# Revert this patch for SLE 15 >SP1 and SUSE Linux >15
%patch2001 -R -p1
%endif

# Fix sphinx-build run...
sed -e "s/sphinx-build-3/sphinx-build-%{python3_version}/" -i docs/hawkey/CMakeLists.txt

%build
%cmake -DPYTHON_DESIRED:FILEPATH=%{__python3} %{!?with_valgrind:-DDISABLE_VALGRIND=1}
%make_build

%if %{with check}
%check
# The test suite doesn't automatically know to look at the "built"
# library, so we force it by creating an LD_LIBRARY_PATH
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}

if [ "$(id -u)" == "0" ] ; then
        cat <<ERROR 1>&2
Package tests cannot be run under superuser account.
Please build the package as non-root user.
ERROR
        exit 1
fi
pushd build
  make ARGS="-V" test
popd

%endif

%install
pushd build
  %make_install
popd

%find_lang %{name}

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname} -f %{name}.lang
%license COPYING
%doc README.md AUTHORS
%{_libdir}/%{name}.so.%{somajor}
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%{_libdir}/%{name}/plugins/README

%files -n python3-%{name}
%{python3_sitearch}/%{name}/

%files -n %{devname}
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{name}/
%{_datadir}/gtk-doc/html/%{name}/

%files -n hawkey-man
%{_mandir}/man3/hawkey.3*

%files -n python3-hawkey
%{python3_sitearch}/hawkey/

%changelog
* Fri Apr 26 2019 Neal Gompa <ngompa13@gmail.com>
- Add patch for SLE to temporarily drop support for Module advisories
  * Patch: libdnf-0.31.0-Revert-support-for-Module-advisories.patch
* Fri Apr 26 2019 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.31.0
  + Installroot now requires absolute path
  + Support "_none_" value for repo option "proxy" (rh#1680272)
  + Add support for Module advisories
  + Add support for xml:base attribute from primary.xml (rh#1691315)
  + Fix detection of Platform ID for modules (rh#1688462)
* Sun Mar 31 2019 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.28.1
  + Enhance modular solver to handle enabled and default module streams differently (rh#1648839)
  + Add support of wild cards for modules (rh#1644588)
  + Exclude module pkgs that have conflict
  + Enhance config parser to preserve order of data, and keep comments and format
  + Improve ARM detection
  + Add support for SHA-384
  + Return empty query if incorrect reldep (rh#1687135)
  + ConfigParser: Improve compatibility with Python ConfigParser and dnf-plugin-spacewalk (rh#1692044)
  + ConfigParser: Unify default set of string represenation of boolean values
  + Fix segfault when interrupting dnf process (rh#1610456)
- Drop backported patches that are part of this release
  * 0001-Reset-callback-to-NULL-RhBug-1637923.patch
  * 0002-reldep-list-Add-glib-AUTOPTR-cleanup.patch
  * 0003-swdb-Put-Swdb-constructors-together.patch
  * 0004-utils-Drop-empty-else-block.patch
  * 0005-transformer-Fix-minor-docstring-typo.patch
  * 0006-repo-Squash-Wmaybe-uninitialized-warning.patch
  * 0007-transaction-Consistently-use-the-same-swdb-variable.patch
  * 0008-transaction-Minor-syntax-tweak.patch
  * 0101-Zchunk-configuration-flags-were-backwards-so-setting.patch
  * 0102-hy_repos-weren-t-being-filled-properly-when-using-zc.patch
- Refresh patches
  * Remove patch: libdnf-0.24.1-with-static-libsolvext.patch
  * Remove patch: libdnf-0.24.1-Switch-default-reposdir-to-etc-dnf-repos.d.patch
  * Add patch: libdnf-0.28.1-with-static-libsolvext.patch
  * Add patch: libdnf-0.28.1-Switch-default-reposdir-to-etc-dnf-repos.d.patch
* Wed Feb 13 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of descriptions.
- Adjust RPM groups.
* Wed Feb 13 2019 Neal Gompa <ngompa13@gmail.com>
- Fix cmake macro pointer to source tree
* Thu Feb  7 2019 Neal Gompa <ngompa13@gmail.com>
- Switch default reposdir to /etc/dnf/repos.d
  * Add patch: libdnf-0.24.1-Switch-default-reposdir-to-etc-dnf-repos.d.patch
* Tue Feb  5 2019 Neal Gompa <ngompa13@gmail.com>
- Rebase to version 0.24.1
  + Add support for RH/Fedora modules
  + Add plugin support (unstable API)
  + Add zchunk support
  + Migrate from YUMDB to new SWDB
  + Rewrite into C++
- Drop Python 2 bindings
- Backport fixes from upstream eliminate various bugs
  * 0001-Reset-callback-to-NULL-RhBug-1637923.patch
  * 0002-reldep-list-Add-glib-AUTOPTR-cleanup.patch
  * 0003-swdb-Put-Swdb-constructors-together.patch
  * 0004-utils-Drop-empty-else-block.patch
  * 0005-transformer-Fix-minor-docstring-typo.patch
  * 0006-repo-Squash-Wmaybe-uninitialized-warning.patch
  * 0007-transaction-Consistently-use-the-same-swdb-variable.patch
  * 0008-transaction-Minor-syntax-tweak.patch
- Add proposed patches for improving zchunk support
  * 0101-Zchunk-configuration-flags-were-backwards-so-setting.patch
  * 0102-hy_repos-weren-t-being-filled-properly-when-using-zc.patch
- Refresh patch for linking to static libsolvext
  * Remove patch: libdnf-0.9.3-with-static-libsolvext.patch
  * Add patch: libdnf-0.24.1-with-static-libsolvext.patch
- Drop patch merged in upstream libdnf
  * 0001-Add-multiversion-kernel-as-a-recognized-installonlyp.patch
* Mon Aug 20 2018 Neal Gompa <ngompa13@gmail.com>
- Refresh patch to fix building against static libsolvext
- Switch to full author identities
* Thu Jan  4 2018 Neal Gompa <ngompa13@gmail.com>
- Ensure SUSE kernel packages are recognized properly
  * New patch: 0001-Add-multiversion-kernel-as-a-recognized-installonlyp.patch
* Mon Nov 13 2017 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.11.1:
  + Make NEVRA parsing stricter
  + Fix segfault with queries if epoch isn't set
  + Improve performance of queries of solvables
* Tue Oct 10 2017 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.11.0:
  + Improves query performance with 'name' and 'arch' filters.
    Also 'nevra' filter will now handle string with or without
    'epoch'.
  + For Python bindings, it renames 'NEVRA._has_just_name()' to
    'NEVRA.has_just_name()' as it's now implemented in the C API.
* Sun Aug 13 2017 Neal Gompa <ngompa13@gmail.com>
- Fix building on openSUSE against static libsolvext
  * New patch: libdnf-0.9.3-with-static-libsolvext.patch
* Sun Aug 13 2017 Neal Gompa <ngompa13@gmail.com>
- Initial packaging based on Mageia package
